@@ -9,23 +9,24 @@ import loopkey_client.exceptions as ex
 
 class Client:
 
-    def __init__(self,  auth_token: Optional[str] = ""):
+    def __init__(self,  auth_token: Optional[str] = "", phone: Optional[str] = "", password: Optional[str] = ""):
         """
         Inits loopkey client.
         :param auth_token: Auth token for loopkey.
+        :param phone: Phone number to be used as user.
+        :param password: Password of loopkey user.
         """
+        self.phone = phone
+        self.password = password
         self.token = auth_token or self.get_auth_token()
         self.auth_dict = {"Authorization": self.token}
 
-    @staticmethod
-    def get_auth_token(phone: Optional[str] = "", password: Optional[str] = "") -> str:
+    def get_auth_token(self) -> str:
         """
         Request an authentication token from loopkey servers.
-        :param phone: Phone number to be used as user.
-        :param password: Password of loopkey user.
         :return: Authentication token.
         """
-        data_dict = {co.PHONE: phone, co.PASS: password}
+        data_dict = {co.PHONE: self.phone, co.PASS: self.password}
 
         response = requests.post(
             co.API_LOGIN_URL,
